======
fitlog
======

fitlog = fast + git + log, 是一款用于辅助用户记录日志和管理代码的工具。

文件结构
--------------------

.. parsed-literal::

    |-setup.py
    |-docs
    |-fitlog
    |  |--- init
    |  |--- fastlog
    |  |--- fastgit
    |  |--- server
    |-test

